/// Copyright Thomas Nagy 2007
/// License: QPL

#ifndef izlth
#define izlth

#include  <QGraphicsPathItem>
#include  <QList>
#include  "con.h"

class QColor;
class QString;
class QGraphicsSceneMouseEvent;
class felu;
class rslt;

class izlt: public QGraphicsPathItem
<%
	public:
		izlt(felu *fldlgz, rslt *alkt, rslt * megkap);

		int type() const <% return gratype(17); %>

		QColor dolog() <%return kidlgz;%>
		void nybnvn(QColor c) <%kidlgz=c;%>

		void hsztzk();

		void targy();

		bool kitzjl;

		felu *korrkt;

		int zandek;
		QColor kidlgz;
		QString fladat;

		void jlnrdz();
		void fnqll();
		void hzzqjt();

		rslt *cel;
		rslt *akdaly;
%>;

#endif

